webfinger-cli 0.0.29

Command-line client for querying WebFinger resources and testing WebFinger servers.
webfinger-cli-0.0.29 is not a library.

Webfinger-cli

Crates.io badge License badge Deps.rs badge

webfinger-cli is a command line tool for querying WebFinger servers. It is built on top of the webfinger-rs library, which provides a transport-agnostic implementation of the WebFinger protocol defined by RFC 7033.

Installation

To install webfinger-cli from source, you can use the following command:

cargo install webfinger-cli --locked

Or use cargo-binstall to install a precompiled binary:

cargo binstall webfinger-cli

Usage

Usage: webfinger [OPTIONS] <RESOURCE> [HOST]

Arguments:
  <RESOURCE>  The resource to fetch
  [HOST]      The host to fetch the webfinger resource from

Options:
  -r, --rel <REL>   The link relation types to fetch
      --insecure    Ignore TLS certificate verification errors
  -v, --verbose...  Increase logging verbosity
  -q, --quiet...    Decrease logging verbosity
  -h, --help        Print help (see more with '--help')

E.g. to get the avatar for a user with the account carol@example.com, you can run:

webfinger acct:carol@example.com --rel http://webfinger.net/rel/avatar

Made with VHS

License

Copyright (c) Josh McKinney

This project is licensed under either of:

Contribution

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.

See CONTRIBUTING.md.